# Copyright (c) Meta Platforms, Inc. and affiliates.

# This source code is licensed under the MIT license found in the
# LICENSE file in the root directory of this source tree.

import subprocess
import os

DIVIDING_LINE = "="*150

class PackageReview:

    @staticmethod
    def create_review(pkgs):
        """ Create reviews for all new packages """
        fails = []
        successes = []
        for pkg in pkgs:
            pkg_data = pkgs[pkg]
            if pkg_data["type"] == "new":
                print(DIVIDING_LINE)
                print(f"Create review for {pkg}")
                print(DIVIDING_LINE)
                if PackageReview.create_review_exec(pkg):
                    successes.append(pkg)
                else:
                    fails.append(pkg)
        if len(successes) + len(fails) == 0:
            print("No new package found to create review.")
            return
        # summary
        print(DIVIDING_LINE)
        print("Summary")
        print(DIVIDING_LINE)
        if len(successes) > 0:
            print("Successfully create review for the following packages:")
            for pkg in successes:
                print(f"      {pkg}")
        if len(fails) > 0:
            print("Failed to create review for the following packages:")
            for pkg in fails:
                print(f"      {pkg}")

    @staticmethod
    def fetch_srpm(pkg):
        """ Get the src.rpm file name in cwd """
        files = os.listdir(os.getcwd())
        for file_name in files:
            if file_name.startswith(pkg) and file_name.endswith(".src.rpm"):
                return file_name
        return 

    @staticmethod
    def create_review_exec(pkg):
        """ Execute creating review for a single package """
        os.chdir(f"{os.getcwd()}/{pkg}")
        if not os.path.exists(f"{pkg}.spec"):
            print('\033[93m'+f"No spec file found for package {pkg}"+'\033[0m')
            os.chdir(f"{os.getcwd()}/..")
            return
        spec_file = f"{pkg}.spec"
        srpm_file = PackageReview.fetch_srpm(pkg)
        if srpm_file == "":
            print('\033[93m'+f"No srpm file found for package {pkg}"+'\033[0m')
            os.chdir(f"{os.getcwd()}/..")
            return
        cmd = f'fedora-create-review {spec_file} {srpm_file}'
        output = subprocess.Popen(cmd, shell=True)
        output.communicate()
        os.chdir(f"{os.getcwd()}/..")
        if output.returncode != 0:
            return False
        else:
            return True