# Copyright (c) Meta Platforms, Inc. and affiliates.

# This source code is licensed under the MIT license found in the
# LICENSE file in the root directory of this source tree.

import unittest
import sys
sys.path.append("..")
from rust_update_set.build import Builder
from dataclasses import dataclass

class BuilderTest(unittest.TestCase):

    def test_analyse_build_order(self):

        @dataclass
        class Test_case:
            dependencies: {}
            expected_order: []

        test_cases = [
            Test_case(
                dependencies={
                    "nu-parser": ["miette", "nu-path", "nu-protocol"], 
                    "miette": ["miette-derive"], 
                    "miette-derive": [], 
                    "nu-path": ["pwd"], 
                    "pwd": [], 
                    "nu-protocol": ["miette", "nu-json", "nu-utils"], 
                    "nu-json": [], 
                    "nu-utils": [], 
                    "nu-engine": ["nu-glob", "nu-path", "nu-protocol", "nu-utils", "sysinfo"], 
                    "nu-glob": [], 
                    "sysinfo": [], 
                    "nu-ansi-term": []
                },
                expected_order=[
                    ['nu-glob', 'pwd', 'nu-json', 'miette-derive', 'nu-utils', 'sysinfo', 'nu-ansi-term'],
                    ['nu-path', 'miette'],
                    ['nu-protocol'],
                    ['nu-parser', 'nu-engine']
                ]
            )
        ]

        for test_case in test_cases:
            dependencies = test_case.dependencies
            expected_order = test_case.expected_order
            copr_builder = Builder({"checkout":{}, "dependencies":dependencies},{},"")
            self.assertEqual([sorted(order) for order in expected_order], [sorted(order) for order in copr_builder.analyse_build_order()])


if __name__ == "__main__":
    unittest.main()
